@@ -216,6 +216,7 @@ class CIBase(ABC):
             "--phylum-release", specified_version,
             "--target", self.args.target,
             "--phylum-token", self.args.token,
+            "--api-uri", self.args.uri,
         ]
         # fmt: on
         cli_path, cli_version = get_phylum_bin_path()
@@ -246,7 +247,7 @@ class CIBase(ABC):
         if bool(subprocess.run(cmd, stdout=subprocess.DEVNULL).returncode):
             raise SystemExit(" [!] A Phylum API key is required to continue.")
 
-        print(f" [+] Using Phylum CLI instance: {cli_version} at {str(cli_path)}")
+        print(f" [+] Using Phylum CLI instance: {cli_version} at {cli_path}")
         return cli_path
 
     @property
